=================
Test presentation
=================

Sample
======

List fragments
--------------

.. revealjs-fragments::

   * First
   * Second
   * Third

Paragraph fragments
-------------------

.. revealjs-fragments::

   Hello world

   This is sphinx-revealjs
